@@ -21,7 +21,7 @@ class Config:
                            os.environ.get("LUNARY_PRIVATE_KEY") or
                            os.environ.get("LUNARY_PUBLIC_KEY") or
                            os.getenv("LUNARY_APP_ID"))
-            self.verbose = verbose if verbose is not None else os.getenv('LUNARY_VERBOSE') is not None 
+            self.verbose = verbose if verbose is not None else (os.getenv('LUNARY_VERBOSE') == 'True' or os.getenv('LUNARY_VERBOSE') == 'true')
             self.api_url = api_url or os.getenv("LUNARY_API_URL") or DEFAULT_API_URL
             self.ssl_verify = not (disable_ssl_verify if disable_ssl_verify is not None else (True if os.environ.get("DISABLE_SSL_VERIFY") == "True" else False))
             self.initialized = True
