@@ -1,3 +1,4 @@
+# used for reconciliating messages with Langchain: https://lunary.ai/docs/features/chats#reconciliate-with-llm-calls--agents
 from contextvars import ContextVar
 
 parent_ctx = ContextVar("parent_ctx", default=None)
@@ -15,10 +16,3 @@ class ParentContextManager:
 
 def parent(id: str) -> ParentContextManager:
     return ParentContextManager(id)
-
-def get_parent():
-  parent = parent_ctx.get()
-  if parent and parent.get("retrieved", False) == False:
-    parent_ctx.set({"message_id": parent["message_id"], "retrieved": True})
-    return parent.get("message_id", None)
-  return None
